dival.reconstructors.learnedgd\_reconstructor module
====================================================

.. automodule:: dival.reconstructors.learnedgd_reconstructor
   :members:
   :undoc-members:
   :show-inheritance:
